@@ -236,6 +236,8 @@ public abstract class Supervisor extends HttpServlet {
 	 */
 	public abstract Forward onIllegalRequest( IllegalRequest ir, RequestParameter req, Page from, Page to );
 
+	private static final Page	null4alias = new NullPage4Alias();
+
 	private void doAction( HttpServletRequest request, HttpServletResponse res ) {
 		HttpSession	session = null;
 		SessionData	data = null;
@@ -288,6 +290,9 @@ public abstract class Supervisor extends HttpServlet {
 					}
 				}
 			}
+			else {
+				path_data.from = null4alias;
+			}
 			if ( path_data == null ) {
 				fw = new Forward( 403 );
 				fw.Action( this, res );
@@ -485,7 +490,7 @@ public abstract class Supervisor extends HttpServlet {
 				res.addHeader( "Cache-Control", "public" );
 			}
 			else {
-				res.addHeader( "Cache-Control", "no-cache, no-store" );
+				//res.addHeader( "Cache-Control", "no-cache, no-store" );
 			}
 			if ( fw != null ) {
 				int	ck_cnt = fw.out_cookie.size();
