@@ -16,19 +16,20 @@ public class Version {
 	 * Paraseleneのバージョン番号を表す文字列。
 	 */
 	public static final String VERSION = "@@@ver";
+	private static final String	TITLE = "Paraselene  Version " + VERSION;
 
 	/**
 	 * Paraseleneのアプリタイトル文字列。
 	 */
 	public static String getTitle() {
-		return "Paraselene  Version " + VERSION;
+		return TITLE;
 	}
 
 	/**
 	 * Paraseleneの著作権表示。
 	 */
 	public static String getCopyRight() {
-		return "Copyright (c) 2009  @@@auth";
+		return "Copyright 2009 @@@auth";
 	}
 }
 
